@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: adjunctions
 version: 4.3
-id: adjunctions-4.3-d8875994d2f5b1ad3b30688ee62d2c4c
-key: adjun_2jxGifh4ACY7V6hNQ5H93y
+id: adjunctions-4.3-efc57e5fce33f38939dda45ec9d74b3b
+key: adjun_9BZLUWJrhVD8XOEwWTBxG8
 license: BSD3
 copyright: Copyright (C) 2011-2014 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -26,23 +26,23 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/adjunctions-4.3
-hs-libraries: HSadjunctions-4.3-2jxGifh4ACY7V6hNQ5H93y
+hs-libraries: HSadjunctions-4.3-9BZLUWJrhVD8XOEwWTBxG8
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-ef08fcd44c0efc29fa5bad32641dc22e
+    comonad-5-caa084d849f0fd836e529854caff7fc2
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    contravariant-1.4-db788d767efca0b89f051d890d0c132d
-    distributive-0.5.0.2-921805b919081e64e9b7d8c792bc35e0
-    free-4.12.4-6d3925740b676008d9dfa2ed61ce0035
+    contravariant-1.4-40742dd1a022cbf40c8c77a36d4f0610
+    distributive-0.5.0.2-161dd77efe370865be21560ce248cc64
+    free-4.12.4-933d8993d0b07bad69ead57266997de9
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    profunctors-5.2-fef53ede72ba72080c6462b04bf9f01b
-    semigroupoids-5.0.1-8962f0a8eeeddfa137860cecf2c3229e
-    semigroups-0.18.0.1-09717ed0a84e1dbeffebbb54d604d271
-    tagged-0.8.2-849e3b2865ae1877e32ec9d4d01c3d0a
+    profunctors-5.2-69458fa119e6a2dfd209808104f4439d
+    semigroupoids-5.0.1-71b3eb635555631c006bdf0054367a98
+    semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
+    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
-    void-0.7.1-9c9ef5053011ca6c1b107003e36c68b3
+    void-0.7.1-662e5f28c19568c0aec0b2de7532ac34
 haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
 haddock-html: /usr/share/doc/haskell-adjunctions/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
